BackpressureOutcome

Enum BackpressureOutcome 

pub enum BackpressureOutcome {
    Accepted,
    DroppedNewest,
    DroppedOldest,
    Blocked,
    TimedOut,
    Rejected,
    Closed,
}
Result a producer observes when it offers a packet to a buffered stream.

Variants



Accepted

The packet was buffered.



DroppedNewest

The buffer was full and this newest packet was dropped.



DroppedOldest

The buffer was full and the oldest buffered packet was dropped to admit this one.



Blocked

The producer is blocked until capacity frees up.



TimedOut

The offer timed out before capacity freed up.



Rejected

The offer was rejected by policy.



Closed

The stream is closed and accepts no further packets.

Implementations

Source

impl BackpressureOutcome

pub fn wire_label(self) -> &'static str

Returns the stable wire label for this outcome.

pub fn symbol(self) -> Symbol

Returns the stream/backpressure/<label> symbol for this outcome.

pub fn from_symbol(symbol: &Symbol) -> Result<Self>

Parses an outcome from its bare or stream/backpressure-qualified symbol.

Returns an error for an unrecognized outcome symbol.