Development-event media and cassettes for the SIM Atelier.
Structs
- DevCassette
- A development cassette backed by the standard
StreamCassetteformat. - DevEvent
- One development event before it is wrapped in a
StreamEnvelope. - DevFault
Report - Result of replaying a development cassette with an injected fault.
- Media
Descriptor - Descriptor for a stream media family carried by
StreamEnvelope.
Functions
- dev_
dropped_ chunks_ diagnostic - Diagnostic emitted when a cassette replay drops development chunks.
- dev_
event_ media - Returns the descriptor for an
ide/event/<kind>development event. - dev_
event_ metadata - Creates a stream metadata record for development events.