pub struct DevCassette { /* private fields */ }Expand description
A development cassette backed by the standard StreamCassette format.
Implementations
Sourceimpl DevCassette
impl DevCassette
Sourcepub fn from_events(stream_id: Symbol, events: Vec<DevEvent>) -> Result<Self>
pub fn from_events(stream_id: Symbol, events: Vec<DevEvent>) -> Result<Self>
Records a development session into a stream cassette.
Sourcepub fn from_stream_cassette(cassette: StreamCassette) -> Result<Self>
pub fn from_stream_cassette(cassette: StreamCassette) -> Result<Self>
Wraps an existing stream cassette as a development cassette.
Sourcepub fn cassette(&self) -> &StreamCassette
pub fn cassette(&self) -> &StreamCassette
Returns the underlying stream cassette.
Sourcepub fn content_hash(&self) -> &str
pub fn content_hash(&self) -> &str
Returns the deterministic cassette content hash.
Sourcepub fn redacted(&self) -> Result<Self>
pub fn redacted(&self) -> Result<Self>
Returns a copy with host paths, host names, and private payloads redacted.
Sourcepub fn validate_golden_fixture(
&self,
path: &str,
) -> Result<StreamGoldenFixtureReport>
pub fn validate_golden_fixture( &self, path: &str, ) -> Result<StreamGoldenFixtureReport>
Delegates golden fixture validation to the underlying stream cassette.
Sourcepub fn replay_content_hash(&self) -> Result<String>
pub fn replay_content_hash(&self) -> Result<String>
Replays the cassette and recomputes the content hash.
Sourcepub fn replay_with_fault(
&self,
plan: &StreamFaultPlan,
) -> Result<DevFaultReport>
pub fn replay_with_fault( &self, plan: &StreamFaultPlan, ) -> Result<DevFaultReport>
Replays the cassette with a stream fault plan applied.