DevEvent

Struct DevEvent 

pub struct DevEvent { /* private fields */ }
One development event before it is wrapped in a StreamEnvelope.

Implementations

Source

impl DevEvent

pub fn new( kind: impl Into<String>, atelier_node: Symbol, latency_class: LatencyClass, payload: Expr, ) -> Result<Self>

Builds a development event with an explicit latency class.

pub fn edit(atelier_node: Symbol, payload: Expr) -> Result<Self>

Builds an interactive edit event.

pub fn validate(atelier_node: Symbol, payload: Expr) -> Result<Self>

Builds an offline validation event.

pub fn refusal(atelier_node: Symbol, payload: Expr) -> Result<Self>

Builds a refusal event for a denied development action.

pub fn with_ticks(self, ticks: Vec<Tick>) -> Result<Self>

Attaches ticks to this event.

pub fn kind(&self) -> &str

Returns the development event kind.

pub fn atelier_node(&self) -> &Symbol

Returns the originating Atelier node id.

pub fn latency_class(&self) -> LatencyClass

Returns the event latency class.

pub fn stream_item(&self) -> Result<StreamItem>

Converts this event to a stream item using ide/event/<kind> data.